package com.learning.item;


import java.util.function.Function;

import com.learning.Learning;
import com.learning.block.CustomBlocks;
import com.learning.component.Foods;

import net.minecraft.item.BlockItem;
import net.minecraft.item.Item;
import net.minecraft.registry.Registries;
import net.minecraft.registry.Registry;
import net.minecraft.registry.RegistryKey;
import net.minecraft.registry.RegistryKeys;
import net.minecraft.util.Identifier;
import net.minecraft.block.Block;
import net.minecraft.component.type.ConsumableComponents;

public class CustomItems {
    public static void registerItems() {
        Learning.LOGGER.info("Registering Items...");
    }

    public static Item toast = register("toast", Toast::new, new Item.Settings().food(Foods.toastFood));
    public static Item bakedToast = register("baked_toast", BakedToast::new, new Item.Settings().food(Foods.bakedToastFood, ConsumableComponents.food().consumeSeconds(0.8f).build()));
    public static Item damageBlock = register(CustomBlocks.damageBlock, false);

    private static Item register(Block block, Boolean useItemTranslateKey) {
        RegistryKey<Item> key = keyOf(Registries.BLOCK.getKey(block).get());
        Item.Settings settings = new Item.Settings().registryKey(key);
        if (!useItemTranslateKey) {
            settings.useBlockPrefixedTranslationKey();
        }
        return register(key, (Item)new BlockItem(block, settings));
        
    }

    private static Item register(String itemId) {
        return register(itemId, new Item.Settings());
    }

    private static Item register(String itemId, Item.Settings settings) {
        return register(itemId, Item::new, settings);
    }
  
    private static Item register(String itemId, Function<Item.Settings, Item> factory, Item.Settings settings) {
        RegistryKey<Item> key = keyOf(itemId);    
        return register(key, factory, settings);
    }

    private static Item register(RegistryKey<Item> key, Function<Item.Settings, Item> factory, Item.Settings settings) {
        return register(key, factory.apply(settings.registryKey(key)));
    }

    private static Item register(RegistryKey<Item> key, Item item) {
        return Registry.register(Registries.ITEM, key, item);

    }

    private static RegistryKey<Item> keyOf(String itemId) {
        return RegistryKey.of(RegistryKeys.ITEM, Identifier.of(Learning.MOD_ID, itemId));
    }

    private static RegistryKey<Item> keyOf(RegistryKey<Block> blockKey) {
        return RegistryKey.of(RegistryKeys.ITEM, blockKey.getValue());
    }
}
